#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 apply-refact
version:              0.14.0.0
visibility:           public
id:                   apply-refact-0.14.0.0-F0qDPk4nlEVG2NSwLUFjNO
key:                  apply-refact-0.14.0.0-F0qDPk4nlEVG2NSwLUFjNO
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  79b028e17e30dfc9a8067052fe3d59c7
exposed:              True
exposed-modules:
    Refact.Apply Refact.Compat Refact.Fixity Refact.Internal
    Refact.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/apply-refact-0.14.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-apply-refact
hs-libraries:         HSapply-refact-0.14.0.0-F0qDPk4nlEVG2NSwLUFjNO
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    extra-1.7.16-DDsIRNN8yrp3ezXLLBhh3F
    filemanip-0.3.6.3-FF9o8sZeeop7GYeA2BrDkW ghc-9.6.6
    ghc-boot-th-9.6.6 ghc-exactprint-1.7.1.0-Hx326wn7TBB3DLdGw6UMSh
    process-1.6.19.0 refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    syb-0.7.3-9nTxFCe6QUcL36iCSC2LiM transformers-0.6.1.0
    uniplate-1.6.13-5HoneKDD9jFL4XpEm3Bwfj
    unix-compat-0.7.4.1-JHcud24i5tBJko1Lg5vR04

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

